@@ -12,7 +12,7 @@ use File::Path ();
 use File::Basename ();
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.21_01';
+$VERSION = '0.21_02';
 
 # Okay, this is the brute-force method of finding out what kind of
 # platform we're on.  I don't know of a systematic way.  These values
@@ -575,13 +575,6 @@ looks in the POD of the module from which it gets the distribution's
 version.  It looks for the first line matching C<$package\s-\s(.+)>,
 and uses the captured text as the abstract.
 
-=item codebase
-
-This can be either a single scalar string, or an array reference of
-strings.  It is required when creating PPD files.  It should be a URL,
-or URLs, to be used as the value for the C<< <CODEBASE> >> tag in the
-generated PPD.
-
 =back
 
 =item subclass()
@@ -664,6 +657,13 @@ With one argument, C<notes($key)> returns the value associated with
 the given key.  With two arguments, C<notes($key, $value)> sets the
 value associated with the given key to C<$value>.
 
+=item config()
+
+Returns a hash reference containing the C<Config.pm> hash, including
+any changes the author or user has specified.  This is a reference to
+the actual internal hash we use, so you probably shouldn't modify
+stuff there.
+
 =item dispatch($action, %args)
 
 This method is also called from the auto-generated C<Build> script.
@@ -1212,6 +1212,15 @@ that directory.
 
 Build a PPD file for your distribution.
 
+This action takes an optional argument C<codebase> which is used in
+the generated ppd file to specify the (usually relative) URL of the
+distribution. By default, this value is the distribution name without
+any path information.
+
+Example:
+
+ perl Build ppd codebase="MSWin32-x86-multi-thread/Module-Build-0.21.tar.gz"
+
 =back
 
 =head2 How Installation Paths are Determined
