@@ -6,6 +6,8 @@ use Module::Build::Base;
 use vars qw(@ISA);
 @ISA = qw(Module::Build::Base);
 
+sub need_prelink_c { 1 }
+
 
 =head1 NAME
 
@@ -56,9 +58,20 @@ sub cull_args {
 }
 
 
+=item manpage_separator
+
+Use '__' instead of '::'.
+
+=cut
+
+sub manpage_separator {
+    return '__';
+}
+
+
 =head1 AUTHOR
 
-Michael G Schwern <schwern@pobox.com>
+Michael G Schwern <schwern@pobox.com>, Ken Williams <ken@mathforum.org>
 
 =head1 SEE ALSO
 
